@@ -214,7 +214,7 @@ class Stock:
 		
 		return info_df, nerd_df
 
-	def price_target(self.ticker, exchange='NASDAQ'): # Automatically find correct stock exchange
+	def price_target(self, exchange='NASDAQ'): # Automatically find correct stock exchange
 		BASE_URL = f'https://www.marketbeat.com/stocks/{exchange}/{self.ticker}/price-target/'
 		soup = _get_soup(BASE_URL)
 		
